summaryrefslogtreecommitdiffstats
path: root/kdbg/dbgdriver.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdbg/dbgdriver.h')
-rw-r--r--kdbg/dbgdriver.h130
1 files changed, 65 insertions, 65 deletions
diff --git a/kdbg/dbgdriver.h b/kdbg/dbgdriver.h
index f5f1f7d..dbc1d49 100644
--- a/kdbg/dbgdriver.h
+++ b/kdbg/dbgdriver.h
@@ -7,9 +7,9 @@
#ifndef DBGDRIVER_H
#define DBGDRIVER_H
-#include <qfile.h>
-#include <qregexp.h>
-#include <qcstring.h>
+#include <ntqfile.h>
+#include <ntqregexp.h>
+#include <ntqcstring.h>
#include <kprocess.h>
#include <queue>
#include <list>
@@ -19,7 +19,7 @@ class VarTree;
class ExprValue;
class ExprWnd;
class KDebugger;
-class QStringList;
+class TQStringList;
/**
@@ -27,14 +27,14 @@ class QStringList;
*/
struct DbgAddr
{
- QString a;
- QString fnoffs;
+ TQString a;
+ TQString fnoffs;
DbgAddr() { }
- DbgAddr(const QString& aa);
+ DbgAddr(const TQString& aa);
DbgAddr(const DbgAddr& src) : a(src.a), fnoffs(src.fnoffs) { }
- void operator=(const QString& aa);
+ void operator=(const TQString& aa);
void operator=(const DbgAddr& src) { a = src.a; fnoffs = src.fnoffs; }
- QString asString() const;
+ TQString asString() const;
bool isEmpty() const { return a.isEmpty(); }
protected:
void cleanAddr();
@@ -83,7 +83,7 @@ enum DbgCommand {
DCprint,
DCprintDeref,
DCprintStruct,
- DCprintQStringStruct,
+ DCprintTQStringStruct,
DCframe,
DCfindType,
DCinfosharedlib,
@@ -142,13 +142,13 @@ struct Breakpoint;
struct CmdQueueItem
{
DbgCommand m_cmd;
- QString m_cmdString;
+ TQString m_cmdString;
bool m_committed; /* just a debugging aid */
// remember which expression when printing an expression
VarTree* m_expr;
ExprWnd* m_exprWnd;
// remember file position
- QString m_fileName;
+ TQString m_fileName;
int m_lineNo;
// the breakpoint info
Breakpoint* m_brkpt;
@@ -156,7 +156,7 @@ struct CmdQueueItem
// whether command was emitted due to direct user request (only set when relevant)
bool m_byUser;
- CmdQueueItem(DbgCommand cmd, const QString& str) :
+ CmdQueueItem(DbgCommand cmd, const TQString& str) :
m_cmd(cmd),
m_cmdString(str),
m_committed(false),
@@ -170,10 +170,10 @@ struct CmdQueueItem
struct IsEqualCmd
{
- IsEqualCmd(DbgCommand cmd, const QString& str) : m_cmd(cmd), m_str(str) { }
+ IsEqualCmd(DbgCommand cmd, const TQString& str) : m_cmd(cmd), m_str(str) { }
bool operator()(CmdQueueItem*) const;
DbgCommand m_cmd;
- const QString& m_str;
+ const TQString& m_str;
};
};
@@ -189,14 +189,14 @@ struct Breakpoint
} type;
bool temporary;
bool enabled;
- QString location;
- QString text; /* text if set using DCbreaktext */
+ TQString location;
+ TQString text; /* text if set using DCbreaktext */
DbgAddr address; /* exact address of breakpoint */
- QString condition; /* condition as printed by gdb */
+ TQString condition; /* condition as printed by gdb */
int ignoreCount; /* ignore next that may hits */
int hitCount; /* as reported by gdb */
// the following items repeat the location, but in a better usable way
- QString fileName;
+ TQString fileName;
int lineNo; /* zero-based line number */
Breakpoint();
bool isOrphaned() const { return id < 0; }
@@ -207,7 +207,7 @@ struct Breakpoint
*/
struct FrameInfo
{
- QString fileName;
+ TQString fileName;
int lineNo; /* zero-based line number */
DbgAddr address; /* exact address of PC */
};
@@ -229,8 +229,8 @@ struct StackFrame : FrameInfo
struct ThreadInfo : FrameInfo
{
int id; /* gdb's number */
- QString threadName; /* the SYSTAG */
- QString function; /* where thread is halted */
+ TQString threadName; /* the SYSTAG */
+ TQString function; /* where thread is halted */
bool hasFocus; /* the thread whose stack we are watching */
};
@@ -239,10 +239,10 @@ struct ThreadInfo : FrameInfo
*/
struct RegisterInfo
{
- QString regName;
- QString rawValue;
- QString cookedValue; /* may be empty */
- QString type; /* of vector register if not empty */
+ TQString regName;
+ TQString rawValue;
+ TQString cookedValue; /* may be empty */
+ TQString type; /* of vector register if not empty */
};
/**
@@ -251,7 +251,7 @@ struct RegisterInfo
struct DisassembledCode
{
DbgAddr address;
- QString code;
+ TQString code;
};
/**
@@ -260,7 +260,7 @@ struct DisassembledCode
struct MemoryDump
{
DbgAddr address;
- QString dump;
+ TQString dump;
};
/**
@@ -277,22 +277,22 @@ public:
DebuggerDriver();
virtual ~DebuggerDriver() = 0;
- virtual QString driverName() const = 0;
+ virtual TQString driverName() const = 0;
/**
* Returns the default command string to invoke the debugger driver.
*/
- virtual QString defaultInvocation() const = 0;
+ virtual TQString defaultInvocation() const = 0;
/**
* Returns a list of options that can be turned on and off.
*/
- virtual QStringList boolOptionList() const = 0;
+ virtual TQStringList boolOptionList() const = 0;
- virtual bool startup(QString cmdStr);
- void setLogFileName(const QString& fname) { m_logFileName = fname; }
+ virtual bool startup(TQString cmdStr);
+ void setLogFileName(const TQString& fname) { m_logFileName = fname; }
protected:
- QString m_runCmd;
+ TQString m_runCmd;
enum DebuggerState {
DSidle, /* gdb waits for input */
@@ -315,7 +315,7 @@ protected:
char* m_output; /* normal gdb output */
size_t m_outputLen; /* amount of data so far accumulated in m_output */
size_t m_outputAlloc; /* space available in m_output */
- std::queue<QByteArray> m_delayedOutput; /* output colleced while we have receivedOutput */
+ std::queue<TQByteArray> m_delayedOutput; /* output colleced while we have receivedOutput */
/* but before signal wroteStdin arrived */
public:
@@ -326,21 +326,21 @@ public:
*/
virtual CmdQueueItem* executeCmd(DbgCommand,
bool clearLow = false) = 0;
- virtual CmdQueueItem* executeCmd(DbgCommand, QString strArg,
+ virtual CmdQueueItem* executeCmd(DbgCommand, TQString strArg,
bool clearLow = false) = 0;
virtual CmdQueueItem* executeCmd(DbgCommand, int intArg,
bool clearLow = false) = 0;
- virtual CmdQueueItem* executeCmd(DbgCommand, QString strArg, int intArg,
+ virtual CmdQueueItem* executeCmd(DbgCommand, TQString strArg, int intArg,
bool clearLow = false) = 0;
- virtual CmdQueueItem* executeCmd(DbgCommand, QString strArg1, QString strArg2,
+ virtual CmdQueueItem* executeCmd(DbgCommand, TQString strArg1, TQString strArg2,
bool clearLow = false) = 0;
virtual CmdQueueItem* executeCmd(DbgCommand, int intArg1, int intArg2,
bool clearLow = false) = 0;
enum QueueMode {
- QMnormal, /* queues the command last */
- QMoverride, /* removes an already queued command */
- QMoverrideMoreEqual /* ditto, also puts the command first in the queue */
+ TQMnormal, /* queues the command last */
+ TQMoverride, /* removes an already queued command */
+ TQMoverrideMoreEqual /* ditto, also puts the command first in the queue */
};
/**
@@ -349,13 +349,13 @@ public:
*/
virtual CmdQueueItem* queueCmd(DbgCommand,
QueueMode mode) = 0;
- virtual CmdQueueItem* queueCmd(DbgCommand, QString strArg,
+ virtual CmdQueueItem* queueCmd(DbgCommand, TQString strArg,
QueueMode mode) = 0;
virtual CmdQueueItem* queueCmd(DbgCommand, int intArg,
QueueMode mode) = 0;
- virtual CmdQueueItem* queueCmd(DbgCommand, QString strArg, int intArg,
+ virtual CmdQueueItem* queueCmd(DbgCommand, TQString strArg, int intArg,
QueueMode mode) = 0;
- virtual CmdQueueItem* queueCmd(DbgCommand, QString strArg1, QString strArg2,
+ virtual CmdQueueItem* queueCmd(DbgCommand, TQString strArg1, TQString strArg2,
QueueMode mode) = 0;
/**
@@ -381,14 +381,14 @@ public:
virtual void interruptInferior() = 0;
/**
* Specifies the command that prints the QString data.
*/
- virtual void setPrintQStringDataCmd(const char* cmd) = 0;
+ virtual void setPrintTQStringDataCmd(const char* cmd) = 0;
/**
- * Parses the output as an array of QChars.
+ * Parses the output as an array of TQChars.
*/
- virtual ExprValue* parseQCharArray(const char* output, bool wantErrorValue, bool qt3like) = 0;
+ virtual ExprValue* parseTQCharArray(const char* output, bool wantErrorValue, bool qt3like) = 0;
/**
* Parses a back-trace (the output of the DCbt command).
@@ -405,7 +405,7 @@ public:
* output values are undefined in this case.
*/
virtual bool parseFrameChange(const char* output, int& frameNo,
- QString& file, int& lineNo, DbgAddr& address) = 0;
+ TQString& file, int& lineNo, DbgAddr& address) = 0;
/**
* Parses a list of breakpoints.
@@ -436,7 +436,7 @@ public:
* @return False if there was no breakpoint.
*/
virtual bool parseBreakpoint(const char* output, int& id,
- QString& file, int& lineNo, QString& address) = 0;
+ TQString& file, int& lineNo, TQString& address) = 0;
/**
* Parses the output of the DCinfolocals command.
@@ -462,13 +462,13 @@ public:
* Parses the output of the DCcd command.
* @return false if the message is an error message.
*/
- virtual bool parseChangeWD(const char* output, QString& message) = 0;
+ virtual bool parseChangeWD(const char* output, TQString& message) = 0;
/**
* Parses the output of the DCexecutable command.
* @return false if an error occured.
*/
- virtual bool parseChangeExecutable(const char* output, QString& message) = 0;
+ virtual bool parseChangeExecutable(const char* output, TQString& message) = 0;
/**
* Parses the output of the DCcorefile command.
@@ -486,18 +486,18 @@ public:
* Parses the output of commands that execute (a piece of) the program.
* @return The inclusive OR of zero or more of the StopFlags.
*/
- virtual uint parseProgramStopped(const char* output, QString& message) = 0;
+ virtual uint parseProgramStopped(const char* output, TQString& message) = 0;
/**
* Parses the output of the DCsharedlibs command.
*/
- virtual QStringList parseSharedLibs(const char* output) = 0;
+ virtual TQStringList parseSharedLibs(const char* output) = 0;
/**
* Parses the output of the DCfindType command.
* @return true if a type was found.
*/
- virtual bool parseFindType(const char* output, QString& type) = 0;
+ virtual bool parseFindType(const char* output, TQString& type) = 0;
/**
* Parses the output of the DCinforegisters command.
@@ -509,7 +509,7 @@ public:
* two addresses could not be found.
*/
virtual bool parseInfoLine(const char* output,
- QString& addrFrom, QString& addrTo) = 0;
+ TQString& addrFrom, TQString& addrTo) = 0;
/**
* Parses the ouput of the DCdisassemble command.
@@ -520,19 +520,19 @@ public:
* Parses a memory dump. Returns an empty string if no error was found;
* otherwise it contains an error message.
*/
- virtual QString parseMemoryDump(const char* output, std::list<MemoryDump>& memdump) = 0;
+ virtual TQString parseMemoryDump(const char* output, std::list<MemoryDump>& memdump) = 0;
/**
* Parses the output of the DCsetvariable command. Returns an empty
* string if no error was found; otherwise it contains an error
* message.
*/
- virtual QString parseSetVariable(const char* output) = 0;
+ virtual TQString parseSetVariable(const char* output) = 0;
/**
* Returns a value that the user can edit.
*/
- virtual QString editableValue(VarTree* value);
+ virtual TQString editableValue(VarTree* value);
protected:
/** Removes all commands from the low-priority queue. */
@@ -550,13 +550,13 @@ protected:
* Helper function that queues the given command string in the
* low-priority queue.
*/
- CmdQueueItem* queueCmdString(DbgCommand cmd, QString cmdString,
+ CmdQueueItem* queueCmdString(DbgCommand cmd, TQString cmdString,
QueueMode mode);
/**
* Helper function that queues the given command string in the
* high-priority queue.
*/
- CmdQueueItem* executeCmdString(DbgCommand cmd, QString cmdString,
+ CmdQueueItem* executeCmdString(DbgCommand cmd, TQString cmdString,
bool clearLow);
void writeCommand();
virtual void commandFinished(CmdQueueItem* cmd) = 0;
@@ -568,11 +568,11 @@ protected:
char m_prompt[10];
size_t m_promptMinLen;
char m_promptLastChar;
- QRegExp m_promptRE;
+ TQRegExp m_promptRE;
// log file
- QString m_logFileName;
- QFile m_logFile;
+ TQString m_logFileName;
+ TQFile m_logFile;
public slots:
void dequeueCmdByVar(VarTree* var);
@@ -604,7 +604,7 @@ signals:
* should NOT be changed).
* @param address specifies the exact address of the PC or is empty.
*/
- void activateFileLine(const QString& file, int lineNo, const DbgAddr& address);
+ void activateFileLine(const TQString& file, int lineNo, const DbgAddr& address);
/**
* This signal is emitted when a command that starts the inferior has
@@ -381,14 +381,14 @@ public:
virtual void interruptInferior() = 0;
/**
- * Specifies the command that prints the QString data.
+ * Specifies the command that prints the TQString data.
*/